@@ -3,44 +3,7 @@ import os
 import sys
 from pathlib import Path
 from six import text_type
-
-
-ALL_ENABLED = object()
-DEFAULT_RULES = [ALL_ENABLED]
-DEFAULT_PRIORITY = 1000
-
-DEFAULT_SETTINGS = {'rules': DEFAULT_RULES,
-                    'exclude_rules': [],
-                    'wait_command': 3,
-                    'require_confirmation': True,
-                    'no_colors': False,
-                    'debug': False,
-                    'priority': {},
-                    'history_limit': None,
-                    'alter_history': True,
-                    'env': {'LC_ALL': 'C', 'LANG': 'C', 'GIT_TRACE': '1'}}
-
-ENV_TO_ATTR = {'THEFUCK_RULES': 'rules',
-               'THEFUCK_EXCLUDE_RULES': 'exclude_rules',
-               'THEFUCK_WAIT_COMMAND': 'wait_command',
-               'THEFUCK_REQUIRE_CONFIRMATION': 'require_confirmation',
-               'THEFUCK_NO_COLORS': 'no_colors',
-               'THEFUCK_DEBUG': 'debug',
-               'THEFUCK_PRIORITY': 'priority',
-               'THEFUCK_HISTORY_LIMIT': 'history_limit',
-               'THEFUCK_ALTER_HISTORY': 'alter_history'}
-
-SETTINGS_HEADER = u"""# The Fuck settings file
-#
-# The rules are defined as in the example bellow:
-#
-# rules = ['cd_parent', 'git_push', 'python_command', 'sudo']
-#
-# The default values are as follows. Uncomment and change to fit your needs.
-# See https://github.com/nvbn/thefuck#settings for more information.
-#
-
-"""
+from . import const
 
 
 class Settings(dict):
@@ -71,8 +34,8 @@ class Settings(dict):
         settings_path = self.user_dir.joinpath('settings.py')
         if not settings_path.is_file():
             with settings_path.open(mode='w') as settings_file:
-                settings_file.write(SETTINGS_HEADER)
-                for setting in DEFAULT_SETTINGS.items():
+                settings_file.write(const.SETTINGS_HEADER)
+                for setting in const.DEFAULT_SETTINGS.items():
                     settings_file.write(u'# {} = {}\n'.format(*setting))
 
     def _get_user_dir_path(self):
@@ -100,14 +63,14 @@ class Settings(dict):
         settings = load_source(
             'settings', text_type(self.user_dir.joinpath('settings.py')))
         return {key: getattr(settings, key)
-                for key in DEFAULT_SETTINGS.keys()
+                for key in const.DEFAULT_SETTINGS.keys()
                 if hasattr(settings, key)}
 
     def _rules_from_env(self, val):
         """Transforms rules list from env-string to python."""
         val = val.split(':')
         if 'DEFAULT_RULES' in val:
-            val = DEFAULT_RULES + [rule for rule in val if rule != 'DEFAULT_RULES']
+            val = const.DEFAULT_RULES + [rule for rule in val if rule != 'DEFAULT_RULES']
         return val
 
     def _priority_from_env(self, val):
@@ -139,8 +102,8 @@ class Settings(dict):
     def _settings_from_env(self):
         """Loads settings from env."""
         return {attr: self._val_from_env(env, attr)
-                for env, attr in ENV_TO_ATTR.items()
+                for env, attr in const.ENV_TO_ATTR.items()
                 if env in os.environ}
 
 
-settings = Settings(DEFAULT_SETTINGS)
+settings = Settings(const.DEFAULT_SETTINGS)
