@@ -1,7 +1,10 @@
 import subprocess
+from thefuck.specific.apt import apt_available
 from thefuck.specific.sudo import sudo_support
 from thefuck.utils import for_app, eager, replace_command
 
+enabled_by_default = apt_available
+
 
 @for_app('apt', 'apt-get', 'apt-cache')
 @sudo_support
