@@ -1,9 +1,9 @@
-import dbm
 import os
 import pickle
 import pkg_resources
 import re
 import shelve
+import six
 from .conf import settings
 from contextlib import closing
 from decorator import decorator
@@ -15,6 +15,13 @@ from warnings import warn
 
 DEVNULL = open(os.devnull, 'w')
 
+if six.PY2:
+    import anydbm
+    shelve_open_error = anydbm.error
+else:
+    import dbm
+    shelve_open_error = dbm.error
+
 
 def memoize(fn):
     """Caches previous calls to the function."""
@@ -40,22 +47,26 @@ memoize.disabled = False
 @memoize
 def which(program):
     """Returns `program` path or `None`."""
+    try:
+        from shutil import which
 
-    def is_exe(fpath):
-        return os.path.isfile(fpath) and os.access(fpath, os.X_OK)
+        return which(program)
+    except ImportError:
+        def is_exe(fpath):
+            return os.path.isfile(fpath) and os.access(fpath, os.X_OK)
 
-    fpath, fname = os.path.split(program)
-    if fpath:
-        if is_exe(program):
-            return program
-    else:
-        for path in os.environ["PATH"].split(os.pathsep):
-            path = path.strip('"')
-            exe_file = os.path.join(path, program)
-            if is_exe(exe_file):
-                return exe_file
+        fpath, fname = os.path.split(program)
+        if fpath:
+            if is_exe(program):
+                return program
+        else:
+            for path in os.environ["PATH"].split(os.pathsep):
+                path = path.strip('"')
+                exe_file = os.path.join(path, program)
+                if is_exe(exe_file):
+                    return exe_file
 
-    return None
+        return None
 
 
 def default_settings(params):
@@ -87,7 +98,7 @@ def get_closest(word, possibilities, n=3, cutoff=0.6, fallback_to_first=True):
 
 @memoize
 def get_all_executables():
-    from thefuck.shells import thefuck_alias, get_aliases
+    from thefuck.shells import shell
 
     def _safe(fn, fallback):
         try:
@@ -95,7 +106,7 @@ def get_all_executables():
         except OSError:
             return fallback
 
-    tf_alias = thefuck_alias()
+    tf_alias = get_alias()
     tf_entry_points = get_installation_info().get_entry_map()\
                                              .get('console_scripts', {})\
                                              .keys()
@@ -104,7 +115,7 @@ def get_all_executables():
             for exe in _safe(lambda: list(Path(path).iterdir()), [])
             if not _safe(exe.is_dir, True)
             and exe.name not in tf_entry_points]
-    aliases = [alias for alias in get_aliases() if alias != tf_alias]
+    aliases = [alias for alias in shell.get_aliases() if alias != tf_alias]
     return bins + aliases
 
 
@@ -217,8 +228,8 @@ def cache(*depends_on):
                     value = fn(*args, **kwargs)
                     db[key] = {'etag': etag, 'value': value}
                     return value
-        except dbm.error:
-            # Caused when going from Python 2 to Python 3
+        except (shelve_open_error, ImportError):
+            # Caused when switching between Python versions
             warn("Removing possibly out-dated cache")
             os.remove(cache_path)
 
@@ -254,3 +265,28 @@ def compatibility_call(fn, *args):
 
 def get_installation_info():
     return pkg_resources.require('thefuck')[0]
+
+
+def get_alias():
+    return os.environ.get('TF_ALIAS', 'fuck')
+
+
+@memoize
+def get_valid_history_without_current(command):
+    def _not_corrected(history, tf_alias):
+        """Returns all lines from history except that comes before `fuck`."""
+        previous = None
+        for line in history:
+            if previous is not None and line != tf_alias:
+                yield previous
+            previous = line
+        if history:
+            yield history[-1]
+
+    from thefuck.shells import shell
+    history = shell.get_history()
+    tf_alias = get_alias()
+    executables = get_all_executables()
+    return [line for line in _not_corrected(history, tf_alias)
+            if not line.startswith(tf_alias) and not line == command.script
+            and line.split(' ')[0] in executables]
